==> beigesoft-webcrud-jar-1.1.4-src.tar.bz2: src/main/java/org/beigesoft/web/factory/FactoryAppBeansMysql.java <==
package org.beigesoft.web.factory;

/*
 * Copyright (c) 2016 Beigesoft ™
 *
 * Licensed under the GNU General Public License (GPL), Version 2.0
 * (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html
 */

import java.sql.ResultSet;

/**
 * <p>Application beans factory for Mysql RDBMS.
 * Cause don't use IOC.
 * Property dataSourceJndiName must be settled!
 * </p>
 *
 * @author Yury Demidenko
 */
public class FactoryAppBeansMysql extends AFactoryAppBeansMysql {

  /**
   * <p>Invoke complex inner factories initialization.</p>
   * @throws Exception - an exception
   **/
  public FactoryAppBeansMysql() throws Exception {
    init();
  }

  //To override:
  /**
   * <p>Initialize inner factories after clear beans or on startup..</p>
   * @throws Exception - an exception
   */
  @Override
  public final synchronized void init() throws Exception {
    FactoryBldServices<ResultSet> factoryBldServices =
      new FactoryBldServices<ResultSet>();
    factoryBldServices.setFactoryAppBeans(this);
    setFactoryBldServices(factoryBldServices);
    FactoryReplicatorXmlHttp<ResultSet> factoryReplicatorXmlHttp =
      new FactoryReplicatorXmlHttp<ResultSet>();
    factoryReplicatorXmlHttp.setFactoryAppBeans(this);
    setFactoryReplicatorXmlHttp(factoryReplicatorXmlHttp);
    FactoryDatabaseWriterXml<ResultSet> factoryDatabaseWriterXml =
      new FactoryDatabaseWriterXml<ResultSet>();
    factoryDatabaseWriterXml.setFactoryAppBeans(this);
    setFactoryDatabaseWriterXml(factoryDatabaseWriterXml);
  }
}

==> beigesoft-webcrud-jar-1.1.5-src.tar.bz2: src/main/java/org/beigesoft/web/factory/FactoryAppBeansMysql.java <==
package org.beigesoft.web.factory;

/*
 * Copyright (c) 2016 Beigesoft ™
 *
 * Licensed under the GNU General Public License (GPL), Version 2.0
 * (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html
 */

import java.sql.ResultSet;

/**
 * <p>Application beans factory for Mysql RDBMS.
 * Cause don't use IOC.
 * Property dataSourceJndiName must be settled!
 * </p>
 *
 * @author Yury Demidenko
 */
public class FactoryAppBeansMysql extends AFactoryAppBeansMysql {

  /**
   * <p>Invoke complex inner factories initialization.</p>
   * @throws Exception - an exception
   **/
  public FactoryAppBeansMysql() throws Exception {
    init();
  }

  //To override:
  /**
   * <p>Initialize inner factories after clear beans or on startup..</p>
   * @throws Exception - an exception
   */
  @Override
  public final synchronized void init() throws Exception {
    FactoryBldServices<ResultSet> factoryBldServices =
      new FactoryBldServices<ResultSet>();
    factoryBldServices.setFactoryAppBeans(this);
    setFactoryBldServices(factoryBldServices);
    FactoryReplicatorXmlHttps<ResultSet> factoryReplicatorXmlHttps =
      new FactoryReplicatorXmlHttps<ResultSet>();
    factoryReplicatorXmlHttps.setFactoryAppBeans(this);
    setFactoryReplicatorXmlHttps(factoryReplicatorXmlHttps);
    FactoryDatabaseWriterXml<ResultSet> factoryDatabaseWriterXml =
      new FactoryDatabaseWriterXml<ResultSet>();
    factoryDatabaseWriterXml.setFactoryAppBeans(this);
    setFactoryDatabaseWriterXml(factoryDatabaseWriterXml);
  }
}
